#!/bin/bash
# Copyright (C) 2004-2012 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana - C3SL/UFPR
# This file is part of le-proinfodata
#
# exec_dialog.sh is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
# USA.

F_MULT="/tmp/.mult.lock"
F_LOCK="/tmp/.dialog.lock"
F_INEP="/opt/seed_mec/SEED2/client/conf/inep"
BACKGROUND="/usr/share/backgrounds/le5-wallpaper1600X1200.png"
LE_EDUBAR_POS="/usr/share/gnome/autostart/le-edubar_position.sh"

function enable_mouse () {
    # Enable mouse right-click and left-click
    xmodmap -e "pointer = default"
}

function disable_mouse () {
    if [[ -z "$1" ]]; then
        # Disable mouse right-click
        xmodmap -e "pointer = 1 2 0 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32"
        xmodmap -e "keycode 64 = "
    else
        # Disable mouse right-click and left-click
        xmodmap -e "pointer = 0 2 0 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32"
        xmodmap -e "keycode 64 = "
    fi
}

function disable_keyboard () {
    # Disable keyboard control-button and alt-button
    xmodmap -e "remove Control = Control_L"
    xmodmap -e "keycode 64 = "
}

function enable_keyboard () {
    # Enable keyboard control-button and alt-button
    xmodmap -e "add Control = Control_L"
    xmodmap -e "keycode 64 = Alt_L Meta_L Alt_L Meta_L Alt_L Meta_L"
}

function call_dialog_inep_mult_off () {
    # Disable mouse right-click
    disable_mouse
    # Disable keyboard control-button and alt-button
    disable_keyboard
    # Set background
    xli -onroot -fillscreen $BACKGROUND
    dialog_inep.sh
    # Reset background to default
    xli -onroot -background black
    # Enable mouse right-click
    enable_mouse
    # Enable keyboard control-button and alt-button 
    enable_keyboard
}

# Disable user interaction with gnome panel
function disable_gnome() {
    local P_EDUBAR=""
    local P_EDUBAR_POS=""
    local P_GPANEL=""

    while true; do
        # Get PID
        P_EDUBAR_POS="$(ps aux | grep "le-edubar_position.sh" | grep -v "grep" \
                       | awk '{print $2}')"
        P_GPANEL=$(pgrep gnome-panel)
        P_EDUBAR=$(pgrep -f "le-edubar -c")

        if [[ -z "$P_GPANEL" ]] ||
           [[ -z "$P_EDUBAR_POS" ]] ||
           [[ -z "$P_EDUBAR" ]]; then
            sleep 1
        else
            break
        fi
    done

    # Disable Edubar and Panel
    kill -stop $P_EDUBAR_POS $P_GPANEL
    kill $P_EDUBAR
}

# Enable user interaction with gnome panel
function enable_gnome() {
    # Get PID
    local P_EDUBAR_POS=$(ps aux | grep "le-edubar_position.sh" | awk '{print $2}')
    local P_GPANEL=$(pgrep gnome-panel)

    # Enable Edubar and Panel
    # NOTE: le-edubar_position.sh will automatically open le-edubar
    kill -cont $P_GPANEL $P_EDUBAR_POS
}

function call_dialog_inep_mult_on () {
    # Disable user interaction
    disable_mouse
    disable_gnome
    # Disable keyboard control-button and alt-button
    disable_keyboard
    # Start Inep Dialog
    dialog_inep.sh
    # Enable user interaction
    enable_gnome
    enable_mouse
    enable_keyboard
}

function warning_dialog_inep_on () {
    # Disable user interaction
    # Disable mouse right-click and left-click
    disable_mouse "all"
    # Disable keyboard control-button and alt-button
    disable_keyboard
    # Warning other INEP setting
    while [ ! -e $F_LOCK ]; do
        echo wait
        sleep 1
    done | zenity --progress --pulsate --no-cancel --auto-close --title="INEP" \
                  --text="Aguarde a configuração do PROINFODATA"
    # Enable user interaction
    enable_keyboard
    enable_mouse
}

export LANG="pt_BR.UTF-8"
# SANITY CHECK -------------------------------------------------------
# Do not run script if we are on live-cd
# or the INEP code is already set
# or we are logging out
if dpkg --get-selections "ubiquity-le" | grep -q 'install$' ||
   [ -f $F_INEP ] ||
   [ -f $F_LOCK ]; then
    exit 0
fi
# --------------------------------------------------------------------

# Check whether the computer is running on a the multiterminal
if dpkg --get-selections "le-multiterminal" | grep -q 'install$'; then
    # In the first call (lightdm) in multiterminal this is script must leave, to be called again after.
    (
        flock -n 200
        if [ $? != "0" ]; then
            warning_dialog_inep_on
        else
            call_dialog_inep_mult_on
            touch $F_LOCK
        fi
    ) 200>$F_MULT
else
    call_dialog_inep_mult_off
    touch $F_LOCK
fi

exit 0
